==> haskell-persistent-template-2.8.2.3-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-template
version:              2.8.2.3
visibility:           public
id:                   persistent-template-2.8.2.3-46ztEZ5VVsk4qdmxx3XiBv
key:                  persistent-template-2.8.2.3-46ztEZ5VVsk4qdmxx3XiBv
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.

category:             Database, Yesod
abi:                  6b611167937813953e5414246c6a0ff0
exposed:              True
exposed-modules:      Database.Persist.TH
import-dirs:          /usr/lib/ghc-8.10.2/site-local/persistent-template-2.8.2.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/persistent-template-2.8.2.3
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/persistent-template-2.8.2.3

hs-libraries:         HSpersistent-template-2.8.2.3-46ztEZ5VVsk4qdmxx3XiBv
depends:
    aeson-1.5.4.0-80igNVFBPru77mSGE86olG base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    http-api-data-0.4.2-utlgo1TcsCC8Xf1OKdFH1
    monad-control-1.0.2.3-7nZAeCYdljCAFyv2NvJZxe
    monad-logger-0.3.35-IJBP9TTa47H9VnHurLgyLW
    path-pieces-0.2.1-3qqfFRSZ4HL4UPuvUVZn5U
    persistent-2.10.5.2-1xVTlyMtbW77qwtnEMjHKL
    template-haskell-2.16.0.0 text-1.2.3.2
    th-lift-instances-0.1.17-J7jH2xMdDv5C5WMwPXrPbv
    transformers-0.5.6.2
    unordered-containers-0.2.12.0-pZah0rMXkZH7Mr1zX4l5d

haddock-interfaces:
    /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock

haddock-html:         /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.8.2.3-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-template
version:              2.8.2.3
visibility:           public
id:                   persistent-template-2.8.2.3-Ene3OMj2C6FBFQ68dgF1FW
key:                  persistent-template-2.8.2.3-Ene3OMj2C6FBFQ68dgF1FW
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.

category:             Database, Yesod
abi:                  0b8fbb26bfe560a858d212c4c03290ba
exposed:              True
exposed-modules:      Database.Persist.TH
import-dirs:          /usr/lib/ghc-8.10.2/site-local/persistent-template-2.8.2.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/persistent-template-2.8.2.3
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/persistent-template-2.8.2.3

hs-libraries:         HSpersistent-template-2.8.2.3-Ene3OMj2C6FBFQ68dgF1FW
depends:
    aeson-1.5.4.0-5vxqgGZiwHzJS2LSOWy84c base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    http-api-data-0.4.2-KmwVG1oaAm27F4ew28fADr
    monad-control-1.0.2.3-J0FITfVUT03AzGWl9sOh2t
    monad-logger-0.3.35-I15beggtPXE7JKjWKep9rH
    path-pieces-0.2.1-3qqfFRSZ4HL4UPuvUVZn5U
    persistent-2.10.5.2-It68MrOfzcG2dtCg5v6KZX
    template-haskell-2.16.0.0 text-1.2.3.2
    th-lift-instances-0.1.17-JDWKviNpcg4FVu553udiS transformers-0.5.6.2
    unordered-containers-0.2.12.0-5Ef7XCamkg9H83KRAEej2p

haddock-interfaces:
    /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock

haddock-html:         /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
